==> evolution-1.4.10.zip: evolution-1.4.10/manager/includes/lang/errormsg/spanish-utf8.inc.php <==
<?php
/**
 * Evo error messages language file
 *
 * @version 1.4
 * @date 31/12/2013
 *
 * @language Spanish
 * @package evo
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "No se produjeron errores.";
$_lang["An error occured!"] = "¡Ocurrió un error!";
$_lang["You don't have enough privileges for this action!"] = "You don't have enough privileges for this action!";
$_lang["ID passed in request is NaN!"] = "ID passed in request is NaN!";
$_lang["The document is locked!"] = "The document is locked!";
$_lang["Too many results returned from database!"] = "Too many results returned from database!";
$_lang["Not enough/ no results returned from database!"] = "Not enough/ no results returned from database!";
$_lang["Couldn't find parent document's name!"] = "Couldn't find parent document's name!";
$_lang["Logging error!"] = "Logging error!";
$_lang["Table to optimise not found in request!"] = "Table to optimise not found in request!";
$_lang["No settings found in request!"] = "No settings found in request!";
$_lang["The document must have a title!"] = "The document must have a title!";
$_lang["No user selected as recipient of this message!"] = "No user selected as recipient of this message!";
$_lang["No group selected as recipient of this message!"] = "No group selected as recipient of this message!";
$_lang["The document was not found!"] = "The document was not found!";
$_lang["Double action (GET & POST) posted!"] = "Double action (GET & POST) posted!";
$_lang["Document cannot be it's own parent!"] = "Document cannot be it's own parent!";
$_lang["Document's ID not passed in request!"] = "Document's ID not passed in request!";
$_lang["New parent not set in request!"] = "New parent not set in request!";
$_lang["don't know the user!" ] = "Incorrect username or password entered!";
$_lang["wrong password!"] = "Incorrect username or password entered!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Due to too many failed logins, you have been blocked!";
$_lang["You are blocked and cannot log in!"] = "You are blocked and cannot log in!";
$_lang["You are blocked and cannot log in! Please try again later."] = "You are blocked and cannot log in! Please try again later.";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "The security code you entered didn't validate! Please try to login again!";

==> evolution-1.4.26.zip: evolution-1.4.26/manager/includes/lang/errormsg/spanish-utf8.inc.php <==
<?php
/**
 * Evo error messages language file
 *
 * @version 1.4
 * @date 31/12/2013
 *
 * @language Spanish
 * @package evo
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "No se produjeron errores.";
$_lang["An error occured!"] = "¡Ocurrió un error!";
$_lang["You don't have enough privileges for this action!"] = "You don't have enough privileges for this action!";
$_lang["ID passed in request is NaN!"] = "ID passed in request is NaN!";
$_lang["The document is locked!"] = "The document is locked!";
$_lang["Too many results returned from database!"] = "Too many results returned from database!";
$_lang["Not enough/ no results returned from database!"] = "Not enough/ no results returned from database!";
$_lang["Couldn't find parent document's name!"] = "Couldn't find parent document's name!";
$_lang["Logging error!"] = "Logging error!";
$_lang["Table to optimise not found in request!"] = "Table to optimise not found in request!";
$_lang["No settings found in request!"] = "No settings found in request!";
$_lang["The document must have a title!"] = "The document must have a title!";
$_lang["No user selected as recipient of this message!"] = "No user selected as recipient of this message!";
$_lang["No group selected as recipient of this message!"] = "No group selected as recipient of this message!";
$_lang["The document was not found!"] = "The document was not found!";
$_lang["Double action (GET & POST) posted!"] = "Double action (GET & POST) posted!";
$_lang["Document cannot be it's own parent!"] = "Document cannot be it's own parent!";
$_lang["Document's ID not passed in request!"] = "Document's ID not passed in request!";
$_lang["New parent not set in request!"] = "New parent not set in request!";
$_lang["don't know the user!" ] = "Incorrect username or password entered or you have been blocked!";
$_lang["wrong password!"] = "Incorrect username or password entered or you have been blocked!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Incorrect username or password entered or you have been blocked!";
$_lang["You are blocked and cannot log in!"] = "Incorrect username or password entered or you have been blocked!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Incorrect username or password entered or you have been blocked!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "The security code you entered didn't validate! Please try to login again!";
